@@ -1,6 +1,6 @@
 --[[
 
-File l3build-check.lua Copyright (C) 2018-2022 The LaTeX Project
+File l3build-check.lua Copyright (C) 2018-2023 The LaTeX Project
 
 It may be distributed and/or modified under the conditions of the
 LaTeX Project Public License (LPPL), either version 1.3c of this
@@ -55,7 +55,10 @@ local remove           = os.remove
 -- Set up the check system files: needed for checking one or more tests and
 -- for saving the test files
 function checkinit()
-  if not options["dirty"] then
+  if options["dirty"] then
+    mkdir(testdir)
+    mkdir(resultdir)
+  else
     cleandir(testdir)
     cleandir(resultdir)
   end
@@ -126,8 +129,8 @@ local function normalize_log(content,engine,errlevels)
     -- Zap line numbers from \show, \showbox, \box_show and the like:
     -- do this before wrapping lines
     line = gsub(line, "^l%.%d+ ", "l. ...")
-    -- Also from lua stack traces.
-    line = gsub(line, "lua:%d+: in function", "lua:...: in function")
+    -- Also from Lua stack traces
+    line = gsub(line, "lua:%d+:", "lua:...:")
     -- Allow for wrapped lines: preserve the content and wrap
     -- Skip lines that have an explicit marker for truncation
     if len(line) == maxprintline  and
@@ -153,6 +156,10 @@ local function normalize_log(content,engine,errlevels)
     if match(line, "^%.+\\XeTeX.?.?.?file") then
       line = gsub(line, pattern, "../%1")
     end
+    -- pdfTeX .enc files
+    if match(line, "%.enc%}") then
+      line = gsub(line,"%{" .. pattern .. "%}","")
+    end
     -- Deal with dates
     if match(line, "[^<]%d%d%d%d[/%-]%d%d[/%-]%d%d") then
         line = gsub(line,"%d%d%d%d[/%-]%d%d[/%-]%d%d","....-..-..")
@@ -553,6 +560,7 @@ local function normalize_pdf(content)
       not match(line,"^%%%%%+") then
       line = gsub(line,"%/ID( ?)%[<[^>]+><[^>]+>]","/ID%1[<ID-STRING><ID-STRING>]")
       line = gsub(line,"%/ID( ?)%[(%b())%2%]","/ID%1[<ID-STRING><ID-STRING>]")
+      line = gsub(line,"Ghost[sS]cript %d+%.%d+%.?%d*","Ghostscript ...")
       new_content = new_content .. line .. os_newline
     end
   end
@@ -777,8 +785,7 @@ function runtest(name, engine, hide, ext, test_type, breakout)
   rmfile(testdir,name .. logext)
   local errlevels = {}
   for i = 1, checkruns do
-    errlevels[i] = run(
-      testdir,
+    errlevels[i] = runcmd(
       -- No use of localdir here as the files get copied to testdir:
       -- avoids any paths in the logs
       os_setenv .. " TEXINPUTS=." .. localtexmf()
@@ -787,12 +794,7 @@ function runtest(name, engine, hide, ext, test_type, breakout)
       os_setenv .. " LUAINPUTS=." .. localtexmf()
         .. (checksearch and os_pathsep or "")
         .. os_concat ..
-      -- Avoid spurious output from (u)pTeX
-      os_setenv .. " GUESS_INPUT_KANJI_ENCODING=0"
-        .. os_concat ..
-      -- Allow for local texmf files
-      os_setenv .. " TEXMFCNF=." .. os_pathsep
-        .. os_concat ..
+      -- ensure epoch settings
       set_epoch_cmd(epoch, forcecheckepoch) ..
       -- Ensure lines are of a known length
       os_setenv .. " max_print_line=" .. maxprintline
@@ -802,7 +804,8 @@ function runtest(name, engine, hide, ext, test_type, breakout)
         .. setup(lvtfile)
         .. (hide and (" > " .. os_null) or "")
         .. os_concat ..
-      runtest_tasks(jobname(lvtfile),i)
+      runtest_tasks(jobname(lvtfile),i),
+      testdir
     )
     -- Break the loop if the result is stable
     if breakout and i < checkruns then
@@ -827,7 +830,7 @@ function runtest(name, engine, hide, ext, test_type, breakout)
   test_type.rewrite(gen_file,new_file,engine,errlevels)
   -- Store secondary files for this engine
   for _,filetype in pairs(auxfiles) do
-    for _,file in pairs(filelist(testdir, filetype)) do
+    for _,file in ipairs(filelist(testdir, filetype)) do
       if match(file,"^" .. name .. "%.[^.]+$") then
         local newname = gsub(file,"(%.[^.]+)$","." .. engine .. "%1")
         if fileexists(testdir .. "/" .. newname) then
@@ -930,7 +933,7 @@ function check(names)
           excludepatterns[num_exclude] = glob_to_pattern(glob .. ext)
         end
         for _,glob in pairs(includetests) do
-          for _,name in pairs(filelist(testfiledir, glob .. ext)) do
+          for _,name in ipairs(filelist(testfiledir, glob .. ext)) do
             local exclude
             for i=1, num_exclude do
               if match(name, excludepatterns[i]) then
@@ -942,7 +945,7 @@ function check(names)
               insert(names,jobname(name))
             end
           end
-          for _,name in pairs(filelist(unpackdir, glob .. ext)) do
+          for _,name in ipairs(filelist(unpackdir, glob .. ext)) do
             local exclude
             for i=1, num_exclude do
               if not match(name, excludepatterns[i]) then
@@ -1027,7 +1030,7 @@ end
 -- A short auxiliary to print the list of differences for check
 function checkdiff()
   print("\n  Check failed with difference files")
-  for _,i in ipairs(filelist(testdir, "*" .. os_diffext)) do
+  for _,i in ipairs(ordered_filelist(testdir, "*" .. os_diffext)) do
     print("  - " .. testdir .. "/" .. i)
   end
   print("")
@@ -1035,7 +1038,7 @@ end
 
 function showfailedlog(name)
   print("\nCheck failed with log file")
-  for _,i in ipairs(filelist(testdir, name..".log")) do
+  for _,i in ipairs(ordered_filelist(testdir, name..".log")) do
     print("  - " .. testdir .. "/" .. i)
     print("")
     local f = open(testdir .. "/" .. i,"r")
@@ -1049,7 +1052,7 @@ end
 
 function showfaileddiff()
   print("\nCheck failed with difference file")
-  for _,i in ipairs(filelist(testdir, "*" .. os_diffext)) do
+  for _,i in ipairs(ordered_filelist(testdir, "*" .. os_diffext)) do
     print("  - " .. testdir .. "/" .. i)
     print("")
     local f = open(testdir .. "/" .. i,"r")
